/*
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 *  Copyright (C) 2008 Liam Girdwood  
 */
 
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include "ascenario.h"

#define OP_LIST 1
#define OP_ADD  2
#define OP_DEL  3
#define OP_SET  4

void print_usage(char *name) {
	printf("Usage: %s <cmd> [<scenario>]\n"
	       " list  - list available scenarios\n"
	       " add <name> - add a new scenario <name>\n"
	       " del <name> - delete scenario <name>\n"
	       " set <name> - apply scenario <name>\n\n", name);
}

int main(int argc, char *argv[])
{
	struct snd_scenario *scn;
	int num, i, op = 0, err, ret = 0;
	const char **list;

	if(argc > 2) {
		if(!strcmp(argv[1], "add"))
			op = OP_ADD;
		else if(!strcmp(argv[1], "del"))
			op = OP_DEL;
		else if(!strcmp(argv[1], "set"))
			op = OP_SET;
	} else if(argc > 1) {
		if(!strcmp(argv[1], "list"))
			op = OP_LIST;
	}

	if(!op) {
		print_usage(argv[0]);
		exit(1);
	}
	
	/* init library */
	scn = snd_scenario_init("default");
	if (scn == NULL) {
		printf("%s: failed to init\n", argv[0]);
		return 0;
	}

	switch (op) {
	case OP_LIST:
		/* get list of scenarios */
		num = snd_scenario_list(scn, &list);
		if (num) {
			for(i = 0 ; i < num ; i++)
				printf("%s\n", list[i]);
		} else {
			printf("%s: no scenarios\n", argv[0]);
			ret = 2;
		}
	break;
	case OP_SET:
		err = snd_scenario_set_scn(scn, argv[2]);
                if (err < 0) {
                        printf("failed to set scenario: %s\n", argv[2]);
			ret = 3;
		}
	break;
	default:
		printf("Not supported yet\n");
	break;
	}
	
	snd_scenario_exit(scn);
	return ret;
}
